==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/kn.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "ಸಂಗ್ರಹ ಅಮಾನ್ಯವಾಗಿದೆ",
    "Unknown error" : "ಗೊತ್ತಿಲ್ಲದ ದೋಷ",
    "All files" : "﻿ಎಲ್ಲಾ ಕಡತಗಳು",
    "Home" : "﻿ಮುಖಪುಟ",
    "Close" : "ಮುಚ್ಚು",
    "Favorites" : "ಅಚ್ಚುಮೆಚ್ಚಿನ",
    "Upload cancelled." : "ವರ್ಗಾವಣೆಯನ್ನು ರದ್ದು ಮಾಡಲಾಯಿತು.",
    "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
    "Rename" : "﻿ಮರುಹೆಸರಿಸು",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Disconnect storage" : "ಸಂಗ್ರಹ ಸಾಧನವನ್ನು ತೆಗೆದುಹಾಕಿ",
    "Unshare" : "ಹಂಚಿಕೆಯನ್ನು ಹಿಂತೆಗೆ",
    "Files" : "﻿ಕಡತಗಳು",
    "Select" : "ಆಯ್ಕೆ ಮಾಡಿ",
    "Pending" : "﻿ಬಾಕಿ ಇದೆ",
    "Unable to determine date" : "﻿ಮುಕ್ತಾಯ ದಿನಾಂಕ ನಿರ್ಧರಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "group" : "﻿ಗುಂಪು",
    "Name" : "﻿ಹೆಸರು",
    "Size" : "﻿ ಪ್ರಮಾಣ",
    "Modified" : "﻿ಬದಲಾಯಿಸಿದ",
    "_%n folder_::_%n folders_" : ["%n ಕೋಶ(ಗಳು)","%n ಕೋಶ(ಗಳು)"],
    "_%n file_::_%n files_" : ["%n ಕಡತ","%n ಕಡತ"],
    "You don’t have permission to upload or create files here" : "﻿ನಿಮಗೆ ಇಲ್ಲಿ ಅಪ್ಲೋಡ್ ಅಥವಾ ಕಡತಗಳನ್ನು ರಚಿಸವ ಅನುಮತಿ ಇಲ್ಲ",
    "_Uploading %n file_::_Uploading %n files_" : ["%n 'ನೆ ಕಡತವನ್ನು ವರ್ಗಾಯಿಸಲಾಗುತ್ತಿದೆ","%n 'ನೆ ಕಡತವನ್ನು ವರ್ಗಾಯಿಸಲಾಗುತ್ತಿದೆ"],
    "New" : "﻿ಹೊಸ",
    "File name cannot be empty." : "ಕಡತ ಹೆಸರು ಖಾಲಿ ಇರುವಂತಿಲ್ಲ.",
    "Favorited" : "ಅಚ್ಚುಮೆಚ್ಚಿನವು",
    "Favorite" : "ಅಚ್ಚುಮೆಚ್ಚಿನ",
    "Folder" : "ಕಡತಕೋಶ",
    "New folder" : "ಹೊಸ ಕಡತಕೋಶ",
    "Upload" : "ವರ್ಗಾಯಿಸಿ",
    "Upload (max. %s)" : "ವರ್ಗಾವಣೆ (ಗರಿಷ್ಠ %s)",
    "Settings" : "ಆಯ್ಕೆ",
    "WebDAV" : "﻿WebDAV",
    "Select all" : "﻿ಎಲ್ಲಾ ಆಯ್ಕೆ ಮಾಡಿ",
    "Upload too large" : "ದೊಡ್ಡ ಪ್ರಮಾಣದ ಪ್ರತಿಗಳನ್ನು ವರ್ಗಾವಣೆ ಮಾಡಲು ಸಾದ್ಯವಿಲ್ಲ",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ನೀವು ವರ್ಗಾಯಿಸಲು ಪ್ರಯತ್ನಿಸುತ್ತಿರುವ ಕಡತಗಳ ಗಾತ್ರ, ಈ ಗಣಕ ಕೋಶದ ಗರಿಷ್ಠ ಕಡತ ಮೀತಿಯಾನ್ನು ಮೀರುವಂತಿಲ್ಲ.",
    "No favorites" : "ಯಾವ ಅಚ್ಚುಮೆಚ್ಚಿನವುಗಳು ಇಲ್ಲ",
    "Files and folders you mark as favorite will show up here" : "ನೀವು ಗುರುತು ಮಾಡಿರುವ ನೆಚ್ಚಿನ ಕಡತ ಮತ್ತು ಕಡತಕೋಶಗಳನ್ನು ಇಲ್ಲಿ ತೋರಿಸಲಾಗುತ್ತಿದೆ",
    "Text file" : "ಸರಳಾಕ್ಷರದ ಕಡತ"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.16.1.zip: owncloud/apps/files/l10n/kn.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "ಸಂಗ್ರಹ ಅಮಾನ್ಯವಾಗಿದೆ",
    "Unknown error" : "ಗೊತ್ತಿಲ್ಲದ ದೋಷ",
    "All files" : "﻿ಎಲ್ಲಾ ಕಡತಗಳು",
    "Close" : "ಮುಚ್ಚು",
    "Favorites" : "ಅಚ್ಚುಮೆಚ್ಚಿನ",
    "Upload cancelled." : "ವರ್ಗಾವಣೆಯನ್ನು ರದ್ದು ಮಾಡಲಾಯಿತು.",
    "You don’t have permission to upload or create files here" : "﻿ನಿಮಗೆ ಇಲ್ಲಿ ಅಪ್ಲೋಡ್ ಅಥವಾ ಕಡತಗಳನ್ನು ರಚಿಸವ ಅನುಮತಿ ಇಲ್ಲ",
    "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
    "Rename" : "﻿ಮರುಹೆಸರಿಸು",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Disconnect storage" : "ಸಂಗ್ರಹ ಸಾಧನವನ್ನು ತೆಗೆದುಹಾಕಿ",
    "Unshare" : "ಹಂಚಿಕೆಯನ್ನು ಹಿಂತೆಗೆ",
    "Files" : "﻿ಕಡತಗಳು",
    "Select" : "ಆಯ್ಕೆ ಮಾಡಿ",
    "Pending" : "﻿ಬಾಕಿ ಇದೆ",
    "Unable to determine date" : "﻿ಮುಕ್ತಾಯ ದಿನಾಂಕ ನಿರ್ಧರಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "group" : "﻿ಗುಂಪು",
    "{newName} already exists" : "ಈಗಾಗಲೇ {newName}  ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ",
    "Name" : "﻿ಹೆಸರು",
    "Size" : "﻿ ಪ್ರಮಾಣ",
    "Modified" : "﻿ಬದಲಾಯಿಸಿದ",
    "_%n folder_::_%n folders_" : ["%n ಕೋಶ(ಗಳು)","%n ಕೋಶ(ಗಳು)"],
    "_%n file_::_%n files_" : ["%n ಕಡತ","%n ಕಡತ"],
    "_Uploading %n file_::_Uploading %n files_" : ["%n 'ನೆ ಕಡತವನ್ನು ವರ್ಗಾಯಿಸಲಾಗುತ್ತಿದೆ","%n 'ನೆ ಕಡತವನ್ನು ವರ್ಗಾಯಿಸಲಾಗುತ್ತಿದೆ"],
    "New" : "﻿ಹೊಸ",
    "\"{name}\" is an invalid file name." : "\"{name}\" ಅಮಾನ್ಯ ಕಡತ ಹೆಸರು.",
    "File name cannot be empty." : "ಕಡತ ಹೆಸರು ಖಾಲಿ ಇರುವಂತಿಲ್ಲ.",
    "Favorited" : "ಅಚ್ಚುಮೆಚ್ಚಿನವು",
    "Favorite" : "ಅಚ್ಚುಮೆಚ್ಚಿನ",
    "Folder" : "ಕಡತಕೋಶ",
    "New folder" : "ಹೊಸ ಕಡತಕೋಶ",
    "Cancel" : "﻿ರದ್ದು",
    "Create" : "ಸೃಷ್ಟಿಸಿ",
    "{newname} already exists" : "ಈಗಾಗಲೇ {newname}  ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ",
    "Upload" : "ವರ್ಗಾಯಿಸಿ",
    "Upload (max. %s)" : "ವರ್ಗಾವಣೆ (ಗರಿಷ್ಠ %s)",
    "Settings" : "ಆಯ್ಕೆ",
    "WebDAV" : "﻿WebDAV",
    "Select all" : "﻿ಎಲ್ಲಾ ಆಯ್ಕೆ ಮಾಡಿ",
    "Upload too large" : "ದೊಡ್ಡ ಪ್ರಮಾಣದ ಪ್ರತಿಗಳನ್ನು ವರ್ಗಾವಣೆ ಮಾಡಲು ಸಾದ್ಯವಿಲ್ಲ",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ನೀವು ವರ್ಗಾಯಿಸಲು ಪ್ರಯತ್ನಿಸುತ್ತಿರುವ ಕಡತಗಳ ಗಾತ್ರ, ಈ ಗಣಕ ಕೋಶದ ಗರಿಷ್ಠ ಕಡತ ಮೀತಿಯಾನ್ನು ಮೀರುವಂತಿಲ್ಲ.",
    "No favorites" : "ಯಾವ ಅಚ್ಚುಮೆಚ್ಚಿನವುಗಳು ಇಲ್ಲ",
    "Files and folders you mark as favorite will show up here" : "ನೀವು ಗುರುತು ಮಾಡಿರುವ ನೆಚ್ಚಿನ ಕಡತ ಮತ್ತು ಕಡತಕೋಶಗಳನ್ನು ಇಲ್ಲಿ ತೋರಿಸಲಾಗುತ್ತಿದೆ",
    "Text file" : "ಸರಳಾಕ್ಷರದ ಕಡತ"
},
"nplurals=2; plural=(n > 1);");
